/* eslint-disable no-unused-vars */
import '../_shared/shared.js'; // not required, our example styling etc.
import Gantt from '../../lib/Gantt/view/Gantt.js';
import ProjectModel from '../../lib/Gantt/model/ProjectModel.js';
import DateHelper from '../../lib/Core/helper/DateHelper.js';
import '../../lib/Gantt/feature/ProjectLines.js';

const project = new ProjectModel({
    eventsData : [{
        id          : 1000,
        name        : 'Task 1',
        percentDone : 25,
        startDate   : '2019-01-01',
        endDate     : '2019-01-03'
    }, {
        id          : 1001,
        name        : 'Task 2',
        percentDone : 50,
        startDate   : '2019-01-03',
        endDate     : '2019-01-05'
    }, {
        id          : 1002,
        name        : 'Task 3',
        percentDone : 75,
        startDate   : '2019-01-05',
        endDate     : '2019-01-08'
    }],
    dependenciesData : [
        { id : 1, fromEvent : 1000, toEvent : 1001 },
        { id : 2, fromEvent : 1001, toEvent : 1002 }
    ]
});

const changeDurations = () => {
    const eventsData = gantt.taskStore.getRange().map(record => {
        const data = record.data;
        return {
            ...data,
            duration : data.duration + 1
        };
    });
    project.loadInlineData({ eventsData });
};

const changeDone = () => {
    const eventsData = gantt.taskStore.getRange().map(record => {
        const data = record.data;
        return {
            ...data,
            percentDone : data.percentDone + 20
        };
    });
    project.loadInlineData({ eventsData });
};

const changeConstraints = () => {
    const eventsData = gantt.taskStore.getRange().map(record => {
        const data = record.data;
        return {
            ...data,
            constraintType : 'startnoearlierthan',
            constraintDate : DateHelper.format(DateHelper.add(data.startDate, 1, 'day'), 'YYYY-MM-DD')
        };
    });
    project.loadInlineData({ eventsData });
};
const changeDates = () => {
    const eventsData = gantt.taskStore.getRange().map(record => {
        const data = record.data;
        return {
            ...data,
            startDate : DateHelper.format(DateHelper.add(data.startDate, 1, 'day'), 'YYYY-MM-DD'),
            endDate   : DateHelper.format(DateHelper.add(data.endDate, 1, 'day'), 'YYYY-MM-DD')
        };
    });
    project.loadInlineData({ eventsData });
};

const gantt = new Gantt({
    appendTo : 'container',

    project,

    dependencyIdField : 'sequenceNumber',

    columns : [
        { type : 'name', width : 250 }
    ],
    features : {
        projectLines : true
    },
    tbar : [{
        text     : 'Change durations',
        onAction : changeDurations
    }, {
        text     : 'Change done',
        onAction : changeDone
    }, {
        text     : 'Change constraints',
        onAction : changeConstraints
    }, {
        text     : 'Change dates - no effect',
        onAction : changeDates
    }]
});
